OC.L10N.register(
    "files_external",
    {
    "Personal" : "شخصي",
    "System" : "النظام",
    "Saved" : "حفظ",
    "Username" : "إسم المستخدم",
    "Password" : "كلمة السر",
    "Save" : "حفظ",
    "App key" : "مفتاح التطبيق",
    "App secret" : "التطبيق السري",
    "Bucket" : "الحزمة",
    "Hostname" : "إسم الإستضافة",
    "Port" : "المنفذ",
    "Region" : "المنطقة",
    "WebDAV" : "WebDAV",
    "URL" : "عنوان الموقع",
    "Local" : "محلي",
    "Location" : "المكان",
    "ownCloud" : "ownCloud",
    "Host" : "المضيف",
    "Share" : "شارك",
    "Name" : "اسم",
    "Never" : "أبدا",
    "Folder name" : "اسم المجلد",
    "Configuration" : "إعداد",
    "Delete" : "إلغاء"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
